@@ -1,6 +1,20 @@
 #ifndef UU_TYPE_H
 #define UU_TYPE_H
 
+#ifndef PERL_VERSION
+# undef SUBVERSION /* OS/390 */
+# include <patchlevel.h>
+# ifndef SUBVERSION
+#   define SUBVERSION 0
+# endif
+# if !defined(PATCHLEVEL)))
+#   include <could_not_find_Perl_patchlevel.h>
+# endif
+# define PERL_REVISION    5
+# define PERL_VERSION     PATCHLEVEL
+# define PERL_SUBVERSION  SUBVERSION
+#endif
+
 #ifndef PERL_VERSION_DECIMAL
 # define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
 #endif
@@ -8,10 +22,15 @@
 # define PERL_DECIMAL_VERSION \
     PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
 #endif
+
 #ifndef PERL_VERSION_LT
 # define PERL_VERSION_LT(r,v,s) \
     (PERL_DECIMAL_VERSION < PERL_VERSION_DECIMAL(r,v,s))
 #endif
+#ifndef PERL_VERSION_EQ
+# define PERL_VERSION_EQ(r,v,s) \
+    (PERL_DECIMAL_VERSION == PERL_VERSION_DECIMAL(r,v,s))
+#endif
 
 
 /* related from SO for gcc:
@@ -54,7 +73,7 @@
 #  endif
 #endif
 
-struct uu {
+struct uu1 {
   U32 time_low;
   U16 time_mid;
   U16 time_high_and_version;
